@@ -105,6 +105,31 @@ impl Rgba32 {
             a: self.a,
         }
     }
+
+    pub fn saturating_scalar_mul_div(self, numerator: u32, denominator: u32) -> Self {
+        fn single_channel(channel: u8, numerator: u32, denominator: u32) -> u8 {
+            let as_u32 = ((channel as u32) * (numerator)) / denominator;
+            as_u32.min(::std::u8::MAX as u32) as u8
+        }
+        Self {
+            r: single_channel(self.r, numerator, denominator),
+            g: single_channel(self.g, numerator, denominator),
+            b: single_channel(self.b, numerator, denominator),
+            a: self.a,
+        }
+    }
+
+    pub const fn normalised_mul(self, other: Self) -> Self {
+        const fn single_channel(a: u8, b: u8) -> u8 {
+            ((a as u32 * b as u32) / 255) as u8
+        }
+        Self {
+            r: single_channel(self.r, other.r),
+            g: single_channel(self.g, other.g),
+            b: single_channel(self.b, other.b),
+            a: self.a,
+        }
+    }
 }
 
 pub const fn rgba32(r: u8, g: u8, b: u8, a: u8) -> Rgba32 {
